Crate praxis

Crate praxis 

Server bootstrap for the Praxis proxy.

Functions

build_full_registry
Build a FilterRegistry with built-in and auto-discovered external filters.
check_root_privilege
Refuse to start when running as root (UID 0) unless allow_root is set.
fatal
Print a fatal error to stderr and exit the process.
init_tracing
Initialize the global tracing subscriber.
load_config
Load configuration from an explicit path, falling back to praxis.yaml in the working directory, then the built-in default.
resolve_config_path
Resolve the config file path without loading the config.
resolve_pipelines
Build a FilterPipeline for each listener by resolving named chains.
run_server
Build filter pipelines using built-in and auto-discovered external filters, register protocols and run the server.
run_server_with_registry
Build filter pipelines from the given registry, register protocols and run the server.