load_config

Function load_config 

pub fn load_config(explicit_path: Option<&str>) -> Result<Config, ProxyError>
Load configuration from an explicit path, falling back to praxis.yaml in the working directory, then the built-in default.

Errors

Returns ProxyError::Config if the resolved config source cannot be loaded or is invalid.

let config = praxis_core::config::load_config(None).unwrap();
assert!(!config.listeners.is_empty());