Server bootstrap for the Praxis proxy.
Functions
- build_
full_ registry - Build a
FilterRegistrywith built-in and auto-discovered external filters. - check_
root_ privilege - Refuse to start when running as root (UID 0) unless
allow_rootis set. - fatal
- Print a fatal error to stderr and exit the process.
- init_
tracing - Initialize the global tracing subscriber.
- load_
config - Load configuration from an explicit path, falling back to
praxis.yamlin the working directory, then the built-in default. - resolve_
config_ path - Resolve the config file path without loading the config.
- resolve_
pipelines - Build a
FilterPipelinefor each listener by resolving named chains. - run_
server - Build filter pipelines using built-in and auto-discovered external filters, register protocols and run the server.
- run_
server_ with_ registry - Build filter pipelines from the given registry, register protocols and run the server.